#
# spec file for package snapshot
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define gstreamer_version 1.20

Name:           snapshot
Version:        48.0.1
Release:        1.1
Summary:        Take pictures and videos
License:        GPL-3.0-or-later
URL:            https://gitlab.gnome.org/GNOME/snapshot
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst

BuildRequires:  appstream-glib
BuildRequires:  cargo-packaging
BuildRequires:  desktop-file-utils
BuildRequires:  liblcms2-devel
BuildRequires:  libseccomp-devel
BuildRequires:  libxml2-tools
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0) >= 2.75
BuildRequires:  pkgconfig(gstreamer-1.0) >= %{gstreamer_version}
BuildRequires:  pkgconfig(gtk4) >= 4.13.6
BuildRequires:  pkgconfig(libadwaita-1) >= 1.7.alpha
## Needed for camerabin
BuildRequires:  pkgconfig(gstreamer-plugins-bad-1.0) >= %{gstreamer_version}
##
BuildRequires:  pkgconfig(gstreamer-video-1.0) >= %{gstreamer_version}
Requires:       gstreamer-plugins-rs

%description
%{summary}.

%lang_package

%prep
%autosetup -p1 -a1

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}

%check
%{cargo_test}
desktop-file-validate %{buildroot}%{_datadir}/applications/org.gnome.Snapshot.desktop
appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/org.gnome.Snapshot.metainfo.xml

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}
%{_datadir}/applications/org.gnome.Snapshot.desktop
%{_datadir}/glib-2.0/schemas/org.gnome.Snapshot.gschema.xml
%{_datadir}/icons/hicolor/scalable/apps/org.gnome.Snapshot.svg
%{_datadir}/icons/hicolor/symbolic/apps/org.gnome.Snapshot-symbolic.svg
%{_datadir}/metainfo/org.gnome.Snapshot.metainfo.xml
# resources.gresource should probably not be packaged, but never mind this early in the development
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/resources.gresource

%files lang -f %{name}.lang

%changelog
* Sat Mar 15 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 48.0.1:
  + Fix dist-vendor script.
* Fri Mar 14 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 48.0:
  + Register app id when app is not sandboxed
  + QR code detection now happens on a thread pool
  + Updated translations.
* Sat Feb  1 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 48.beta:
  + Improve bottom sheet labels and size
  + Properly detects missing camera permissions
  + Detect codes no more than once a second
  + Hide gallery button in QR code detection mode
  + Updated translations.
* Tue Jan 14 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 48.alpha.2:
  + Use .cargo/config.toml for the cargo-vendor config
  + Add QR code detection
  + Include left-side window controls
  + Add debug output via flag
* Sun Dec 15 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to vesion 48.alpha:
  + Fix opening multiple preference windows
  + Improve offloading performance
  + Add a NEWS file
  + Camera:
  - Port to AdwToggleGroup
  - Port to AdwMultiLayoutView
  + Remove once_cell dependency
  + window: Use adw::AboutDialog::from_appdata
* Sat Oct 12 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.1:
  + Optimize caps selection for 16:9.
  + Only get devices from pipewire.
- Add gstreamer-plugins-rs Requires, Snapshot needs the
  gst-plugin-gtk4 provided by it during runtime.
* Sun Sep 15 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.0.1:
  + Fix a build issue where the tarballs would be generated with
    missing vendor packages.
* Sun Sep 15 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.0:
  + Improve recording pipeline
  + Improve video player performance
  + Offload DMABUFs in Viewfinder
  + Squash various bugs
  + Update dependencies
  + Use glycin for viewing images
  + Updated translations.
- Cleanup spec for old obsolete rust exports.
* Fri Aug 30 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.beta:
  + Offload DMABUFs in Viewfinder
  + Improve recording pipeline
  + Update dependencies
  + Squash various bugs
  + Updated translations.
- Add liblcms2-devel and libseccomp-devel BuildRequires: new
  dependencies.
* Tue May  7 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.3:
  + Assume cameras are front cameras by default.
  + Update caps when switching cameras.
  + Do not store caps file on errors.
  + Avoid unnecessary stream restarts.
  + Updated translations.
* Fri Apr 12 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.2:
  + Disable portal.
  + Always use prefered caps.
* Thu Apr  4 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.1:
  + Require only rustc 1.70.
  + Fix framerate comparison.
  + Filter out more IR cameras.
  + Update translations.
* Fri Mar 15 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.0:
  + Update to zbus 4.0.
  + Improve default camera resolution selection.
  + Update Dependencies.
  + Update translations.
* Mon Mar  4 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.rc:
  + Improve default camera resolution selection.
* Mon Feb 19 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.beta:
  + Better camera resolution and formatting.
  + Update Dependencies.
  + Update translations.
* Sat Dec  9 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.1:
  + Various Bugfixes
  + Update internal libraries
  + Updated translations.
- Drop cargo_config as source, no longer needed.
* Sat Sep 16 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.0:
  + Various Bugfixes
  + Use pipewire node description to name cameras
  + Updated translations.
* Sat Aug 19 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.beta:
  + Improve Video Player controller.
  + Improved accessibility.
  + Update styles throughout the app.
  + Squash various bugs.
  + Updated translations.
* Mon Jul 24 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add back cargo_audit to _service, now that it is back in working
  order.
* Tue Jul 11 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.alpha:
  + Minor release with updates to various dependencies.
  + Update Aperture to v0.2, update Rust to 1.70
  + Update to Libadwaita 1.4, use new adaptive components
  + Show all window controls on the top of the window
  + Improved accessibility
  + Squash various bugs
  + Updated translations.
* Mon May 22 2023 Luciano Santos <luc14n0@opensuse.org>
- Update to version 44.2:
  + Many improvements and fixes.
  + Updated translations.
- Add gstreamer-plugins-bad-1.0 pkgconfig module as a new build
  requirement for camerabin.
* Fri Mar 31 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Initial packaging for openSUSE.
